summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorFlorian Dold <florian.dold@gmail.com>2019-01-10 21:06:52 +0100
committerFlorian Dold <florian.dold@gmail.com>2019-01-10 21:06:52 +0100
commitb8713c9c7b79ecd2af6d273fe182a8d0de798a6a (patch)
tree7c981b822b3956a39c15076f492b57ba8b1d7082
parent2883e1786a55096c5fe95e4c1a9843419f03f249 (diff)
downloaddeployment-b8713c9c7b79ecd2af6d273fe182a8d0de798a6a.tar.gz
deployment-b8713c9c7b79ecd2af6d273fe182a8d0de798a6a.tar.bz2
deployment-b8713c9c7b79ecd2af6d273fe182a8d0de798a6a.zip
comments
-rw-r--r--guix/custom-packages/postfix.scm12
1 files changed, 9 insertions, 3 deletions
diff --git a/guix/custom-packages/postfix.scm b/guix/custom-packages/postfix.scm
index 3451b22..9927145 100644
--- a/guix/custom-packages/postfix.scm
+++ b/guix/custom-packages/postfix.scm
@@ -35,10 +35,11 @@
("lmdb" ,lmdb)))
(build-system gnu-build-system)
(arguments
- `(#:tests? #f
+ `(#:tests? #f ; Postfix does not come with any tests.
#:phases
(modify-phases %standard-phases
(replace 'configure
+ ;; Postfix does not have a standard "./configure".
(lambda* (#:key outputs inputs configure-flags #:allow-other-keys)
(define (dir-setting name dir)
(string-append name "=" (assoc-ref outputs "out") dir))
@@ -87,6 +88,8 @@
"AUXLIBS_PGSQL=-lpq"
"AUXLIBS_SQLITE=-lsqlite3 -lpthread")))
(replace 'install
+ ;; Postfix's "make install" is interactive, we work around this
+ ;; by directly calling postfix-install with the right arguments.
(lambda* (#:key outputs inputs configure-flags #:allow-other-keys)
(substitute* "postfix-install"
(("^SHELL=/bin/sh$") "SHELL=sh")
@@ -107,10 +110,13 @@
"-non-interactive"
"-package")))
(add-after 'install 'patch-master-cf
+ ;; Make sure that the default main.cf does not contain wrong/confusing
+ ;; paths.
(lambda* (#:key outputs inputs configure-flags #:allow-other-keys)
(define comment
- "# Guix: This value should usually not be changed, as the
-# compiled-in default value correctly points to the Guix store already.")
+ "# Note for Guix: This parameter should usually not be
+# changed, as the compiled-in default in the postfix
+# binaries already points to the Guix store.")
(substitute* (string-append
(assoc-ref outputs "out")
"/etc/postfix/main.cf")